#
# prog-size-fishing.R, 15 Jun 24
# Data from:
#
# Empirical analysis of the relationship between {CC} and {SLOC} in a large corpus of {Java} methods and {C} functions
# Davy Landman and Alexander Serebrenik and Eric Bouwers and Jurgen J. Vinju
#

library("colorspace")
library("plyr")


par(bty="l")
par(las=1)
par(pch="+")
pal_col=rainbow(2)



# The number of functions in a project
count_func=function(df)
{
return(nrow(df))
}


# The number of LOC in a project
sum_LOC=function(df)
{
return(sum(df$sloc))
}


prog_LOC_frac=function(LOCs, fraction)
{
num_prog=trunc(fraction*length(LOCs))
num_LOC=LOCs[num_prog]
text(num_prog, num_LOC, labels=paste0(num_LOC, "\n", trunc(100*fraction), "%"), cex=1.2)

}



la=read.csv("Landman.csv.xz" , as.is=TRUE)

prog_func=ddply(la, .(project), count_func)
prog_LOC=ddply(la, .(project), sum_LOC)

plot(count(prog_func$V1), log="xy", col=pal_col[1],
	xlab="Functions", ylab="Programs")

LOC_cnt=count(prog_LOC$V1)
plot(LOC_cnt, log="xy", col=pal_col[1],
	xlab="LOC", ylab="Programs")


# Plot used in blog post

# LOC
ord_prog_LOC=prog_LOC$V1[order(prog_LOC$V1)]
plot(ord_prog_LOC, log="y", type="l", col=pal_col[1], lwd=2,
	xaxs="i",
	xlim=c(0, 1.02*length(ord_prog_LOC)),
	xlab="Program", ylab="LOC/Methods")

prog_LOC_frac(ord_prog_LOC, 0.05)
prog_LOC_frac(ord_prog_LOC, 0.25)
prog_LOC_frac(ord_prog_LOC, 0.5)
prog_LOC_frac(ord_prog_LOC, 0.75)
prog_LOC_frac(ord_prog_LOC, 0.95)


# Methods
ord_prog_FUNC=prog_func$V1[order(prog_func$V1)]
lines(ord_prog_FUNC, col=pal_col[2], lwd=2)

prog_LOC_frac(ord_prog_FUNC, 0.05)
prog_LOC_frac(ord_prog_FUNC, 0.25)
prog_LOC_frac(ord_prog_FUNC, 0.5)
prog_LOC_frac(ord_prog_FUNC, 0.75)
prog_LOC_frac(ord_prog_FUNC, 0.95)


legend("topleft", legend=c("LOC", "Methods"),
                        fill=pal_col, border="white", bty="n", cex=1.2)

dev.copy(dev=png, file="prog_LOC_METH.png")
dev.off()

